@@ -1,8 +1,9 @@
-
+import mock
 from cqlengine import ALL, CACHING_ALL, CACHING_NONE
+from cqlengine.connection import get_session
 from cqlengine.exceptions import CQLEngineException
 from cqlengine.management import  get_fields, sync_table, drop_table
-from cqlengine.tests.base import BaseCassEngTestCase
+from cqlengine.tests.base import BaseCassEngTestCase, CASSANDRA_VERSION
 from cqlengine import management
 from cqlengine.tests.query.test_queryset import TestModel
 from cqlengine.models import Model
@@ -121,10 +122,7 @@ class ModelWithTableProperties(Model):
     __bloom_filter_fp_chance__ = 0.76328
     __caching__ = CACHING_ALL
     __comment__ = 'TxfguvBdzwROQALmQBOziRMbkqVGFjqcJfVhwGR'
-    __default_time_to_live__ = 4756
     __gc_grace_seconds__ = 2063
-    __index_interval__ = 98706
-    __memtable_flush_period_in_ms__ = 43681
     __populate_io_cache_on_flush__ = True
     __read_repair_chance__ = 0.17985
     __replicate_on_write__ = False
@@ -132,6 +130,11 @@ class ModelWithTableProperties(Model):
 
     key = columns.UUID(primary_key=True)
 
+# kind of a hack, but we only test this property on C >= 2.0
+if CASSANDRA_VERSION >= 20:
+    ModelWithTableProperties.__memtable_flush_period_in_ms__ = 43681
+    ModelWithTableProperties.__index_interval__ = 98706
+    ModelWithTableProperties.__default_time_to_live__ = 4756
 
 class TablePropertiesTests(BaseCassEngTestCase):
 
@@ -139,59 +142,64 @@ class TablePropertiesTests(BaseCassEngTestCase):
         drop_table(ModelWithTableProperties)
 
     def test_set_table_properties(self):
+
         sync_table(ModelWithTableProperties)
-        self.assertDictContainsSubset({
-            'bloom_filter_fp_chance': 0.76328,
-            'caching': CACHING_ALL,
-            'comment': 'TxfguvBdzwROQALmQBOziRMbkqVGFjqcJfVhwGR',
-            'default_time_to_live': 4756,
-            'gc_grace_seconds': 2063,
-            'index_interval': 98706,
-            'memtable_flush_period_in_ms': 43681,
-            'populate_io_cache_on_flush': True,
-            'read_repair_chance': 0.17985,
-            'replicate_on_write': False,
-            # For some reason 'dclocal_read_repair_chance' in CQL is called
-            # just 'local_read_repair_chance' in the schema table.
-            # Source: https://issues.apache.org/jira/browse/CASSANDRA-6717
+        expected = {'bloom_filter_fp_chance': 0.76328,
+                    'caching': CACHING_ALL,
+                    'comment': 'TxfguvBdzwROQALmQBOziRMbkqVGFjqcJfVhwGR',
+                    'gc_grace_seconds': 2063,
+                    'populate_io_cache_on_flush': True,
+                    'read_repair_chance': 0.17985,
+                    'replicate_on_write': False
+                     # For some reason 'dclocal_read_repair_chance' in CQL is called
+                     #  just 'local_read_repair_chance' in the schema table.
+                     #  Source: https://issues.apache.org/jira/browse/CASSANDRA-6717
+                     #  TODO: due to a bug in the native driver i'm not seeing the local read repair chance show up
+                     # 'local_read_repair_chance': 0.50811,
+                    }
 
-            # TODO: due to a bug in the native driver i'm not seeing the local read repair chance show up
-            #'local_read_repair_chance': 0.50811,
+        if CASSANDRA_VERSION >= 20:
+            expected['default_time_to_live'] = 4756
+            expected['index_interval'] = 98706
+            expected['memtable_flush_period_in_ms'] = 43681
 
-        }, management.get_table_settings(ModelWithTableProperties).options)
+        self.assertDictContainsSubset(expected, management.get_table_settings(ModelWithTableProperties).options)
 
     def test_table_property_update(self):
         ModelWithTableProperties.__bloom_filter_fp_chance__ = 0.66778
         ModelWithTableProperties.__caching__ = CACHING_NONE
         ModelWithTableProperties.__comment__ = 'xirAkRWZVVvsmzRvXamiEcQkshkUIDINVJZgLYSdnGHweiBrAiJdLJkVohdRy'
-        ModelWithTableProperties.__default_time_to_live__ = 65178
         ModelWithTableProperties.__gc_grace_seconds__ = 96362
-        ModelWithTableProperties.__index_interval__ = 94207
-        ModelWithTableProperties.__memtable_flush_period_in_ms__ = 60210
+
         ModelWithTableProperties.__populate_io_cache_on_flush__ = False
         ModelWithTableProperties.__read_repair_chance__ = 0.2989
         ModelWithTableProperties.__replicate_on_write__ = True
         ModelWithTableProperties.__dclocal_read_repair_chance__ = 0.12732
 
+        if CASSANDRA_VERSION >= 20:
+            ModelWithTableProperties.__default_time_to_live__ = 65178
+            ModelWithTableProperties.__memtable_flush_period_in_ms__ = 60210
+            ModelWithTableProperties.__index_interval__ = 94207
+
         sync_table(ModelWithTableProperties)
 
         table_settings = management.get_table_settings(ModelWithTableProperties).options
 
-        self.assertDictContainsSubset({
-            'bloom_filter_fp_chance': 0.66778,
-            'caching': CACHING_NONE,
-            'comment': 'xirAkRWZVVvsmzRvXamiEcQkshkUIDINVJZgLYSdnGHweiBrAiJdLJkVohdRy',
-            'default_time_to_live': 65178,
-            'gc_grace_seconds': 96362,
-            'index_interval': 94207,
-            'memtable_flush_period_in_ms': 60210,
-            'populate_io_cache_on_flush': False,
-            'read_repair_chance': 0.2989,
-            'replicate_on_write': True,
+        expected = {'bloom_filter_fp_chance': 0.66778,
+                    'caching': CACHING_NONE,
+                     'comment': 'xirAkRWZVVvsmzRvXamiEcQkshkUIDINVJZgLYSdnGHweiBrAiJdLJkVohdRy',
+                     'gc_grace_seconds': 96362,
+                     'populate_io_cache_on_flush': False,
+                     'read_repair_chance': 0.2989,
+                     'replicate_on_write': True  # TODO see above comment re: native driver missing local read repair chance
+                     #  'local_read_repair_chance': 0.12732,
+                    }
+        if CASSANDRA_VERSION >= 20:
+             expected['memtable_flush_period_in_ms'] = 60210
+             expected['default_time_to_live'] = 65178
+             expected['index_interval'] = 94207
 
-            # TODO see above comment re: native driver missing local read repair chance
-            # 'local_read_repair_chance': 0.12732,
-        }, table_settings)
+        self.assertDictContainsSubset(expected, table_settings)
 
 
 class SyncTableTests(BaseCassEngTestCase):
@@ -237,3 +245,30 @@ class NonModelFailureTest(BaseCassEngTestCase):
     def test_failure(self):
         with self.assertRaises(CQLEngineException):
             sync_table(self.FakeModel)
+
+
+def test_static_columns():
+    class StaticModel(Model):
+        id = columns.Integer(primary_key=True)
+        c = columns.Integer(primary_key=True)
+        name = columns.Text(static=True)
+
+    drop_table(StaticModel)
+
+    from mock import patch
+
+    from cqlengine.connection import get_session
+    session = get_session()
+
+    with patch.object(session, "execute", side_effect=Exception) as m:
+        try:
+            sync_table(StaticModel)
+        except:
+            pass
+
+    assert m.call_count > 0
+    statement = m.call_args[0][0].query_string
+    assert '"name" text static' in statement, statement
+
+
+
